summaryrefslogtreecommitdiffstats
path: root/WebCore/editing/ReplaceNodeWithSpanCommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'WebCore/editing/ReplaceNodeWithSpanCommand.h')
-rw-r--r--WebCore/editing/ReplaceNodeWithSpanCommand.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/WebCore/editing/ReplaceNodeWithSpanCommand.h b/WebCore/editing/ReplaceNodeWithSpanCommand.h
index 7b375b6..0154f29 100644
--- a/WebCore/editing/ReplaceNodeWithSpanCommand.h
+++ b/WebCore/editing/ReplaceNodeWithSpanCommand.h
@@ -37,23 +37,23 @@ namespace WebCore {
class HTMLElement;
-// More accurately, this is ReplaceNodeWithSpanPreservingChildrenAndAttributesCommand
-class ReplaceNodeWithSpanCommand : public CompositeEditCommand {
+// More accurately, this is ReplaceElementWithSpanPreservingChildrenAndAttributesCommand
+class ReplaceNodeWithSpanCommand : public SimpleEditCommand {
public:
- static PassRefPtr<ReplaceNodeWithSpanCommand> create(PassRefPtr<Node> node)
+ static PassRefPtr<ReplaceNodeWithSpanCommand> create(PassRefPtr<HTMLElement> element)
{
- return adoptRef(new ReplaceNodeWithSpanCommand(node));
+ return adoptRef(new ReplaceNodeWithSpanCommand(element));
}
HTMLElement* spanElement() { return m_spanElement.get(); }
private:
- ReplaceNodeWithSpanCommand(PassRefPtr<Node>);
+ ReplaceNodeWithSpanCommand(PassRefPtr<HTMLElement>);
virtual void doApply();
virtual void doUnapply();
- RefPtr<Node> m_node;
+ RefPtr<HTMLElement> m_elementToReplace;
RefPtr<HTMLElement> m_spanElement;
};